#[non_exhaustive]pub enum KbkdfError {
ZeroLength,
OutputTooLong,
}Expand description
Error returned by the KBKDF entry points.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroLength
The requested output length was zero. SP 800-108r1 derives at least one PRF block, so a zero-length request is rejected as a likely caller bug.
OutputTooLong
The requested output length cannot be produced because the number of
PRF blocks would overflow the 32-bit counter i.